# ComicInfo.xml plugin for Comic Tagger

A plugin for [ComicTagger](https://github.com/comictagger/comictagger/releases) to allow the use of the extensions to the ComicInfo.xml metadata schema by the [Anansi Project]
This plugin is included in binary releases of ComicTagger.

[Anansi Project]: https://github.com/anansi-project/comicinfo
